@@ -22,7 +22,8 @@
 # Imports
 #
 from enum import auto, unique
-from telegram_payment_bot.config.configurable_object import ConfigurableTypes, ConfigurableObject
+
+from telegram_payment_bot.config.config_object import ConfigObject, ConfigTypes
 
 
 #
@@ -31,7 +32,7 @@ from telegram_payment_bot.config.configurable_object import ConfigurableTypes, C
 
 # Bot configuration types
 @unique
-class BotConfigTypes(ConfigurableTypes):
+class BotConfigTypes(ConfigTypes):
     API_ID = auto()
     API_HASH = auto()
     BOT_TOKEN = auto()
@@ -84,5 +85,5 @@ class BotConfigTypes(ConfigurableTypes):
 #
 
 # Bot configuration class
-class BotConfig(ConfigurableObject):
+class BotConfig(ConfigObject):
     pass
