@@ -23,15 +23,17 @@
 #
 from abc import ABC, abstractmethod
 from typing import Any
+
 import pyrogram
 from pyrogram.errors import RPCError
+
 from telegram_payment_bot.auth_user.authorized_users_list import AuthorizedUsersList
 from telegram_payment_bot.auth_user.authorized_users_message_sender import AuthorizedUsersMessageSender
 from telegram_payment_bot.command.command_data import CommandData
-from telegram_payment_bot.config.configurable_object import ConfigurableObject
-from telegram_payment_bot.misc.helpers import ChatHelper, UserHelper
+from telegram_payment_bot.config.config_object import ConfigObject
 from telegram_payment_bot.logger.logger import Logger
 from telegram_payment_bot.message.message_sender import MessageSender
+from telegram_payment_bot.misc.helpers import ChatHelper, UserHelper
 from telegram_payment_bot.translator.translation_loader import TranslationLoader
 
 
@@ -45,7 +47,7 @@ from telegram_payment_bot.translator.translation_loader import TranslationLoader
 class CommandBase(ABC):
 
     client: pyrogram.Client
-    config: ConfigurableObject
+    config: ConfigObject
     logger: Logger
     translator: TranslationLoader
     message: pyrogram.types.Message
@@ -55,7 +57,7 @@ class CommandBase(ABC):
     # Constructor
     def __init__(self,
                  client: pyrogram.Client,
-                 config: ConfigurableObject,
+                 config: ConfigObject,
                  logger: Logger,
                  translator: TranslationLoader) -> None:
         self.client = client
@@ -104,7 +106,10 @@ class CommandBase(ABC):
                      msg: str) -> None:
         if self._IsQuietMode():
             if not self._IsChannel():
-                self.message_sender.SendMessage(self.cmd_data.User(), msg)
+                cmd_user = self.cmd_data.User()
+                if cmd_user is None:
+                    return
+                self.message_sender.SendMessage(cmd_user, msg)
             else:
                 self._SendMessageToAuthUsers(msg)
         else:
@@ -128,14 +133,18 @@ class CommandBase(ABC):
     # Get if user is authorized
     def _IsUserAuthorized(self) -> bool:
         if not self._IsChannel():
-            return AuthorizedUsersList(self.config).IsUserPresent(self.cmd_data.User())
+            user = self.cmd_data.User()
+            return user is not None and AuthorizedUsersList(self.config).IsUserPresent(user)
         # In channels only admins can write, so we consider the user authorized since there is no way to know the specific user
         # This is a limitation for channels only
         return True
 
     # Get if chat is private
     def _IsPrivateChat(self) -> bool:
-        return ChatHelper.IsPrivateChat(self.cmd_data.Chat(), self.cmd_data.User())
+        cmd_user = self.cmd_data.User()
+        if cmd_user is None:
+            return False
+        return ChatHelper.IsPrivateChat(self.cmd_data.Chat(), cmd_user)
 
     # Get if quiet mode
     def _IsQuietMode(self) -> bool:
