@@ -23,18 +23,17 @@
 #
 from enum import Enum, auto, unique
 from typing import Any, Dict, Type
+
 import pyrogram
+
 from telegram_payment_bot.command.command_base import CommandBase
 from telegram_payment_bot.command.commands import (
-    HelpCmd, AliveCmd, SetTestModeCmd, IsTestModeCmd, AuthUsersCmd,
-    ChatInfoCmd, UsersListCmd, InviteLinkCmd, VersionCmd,
-    CheckNoUsernameCmd, RemoveNoUsernameCmd,
-    SetCheckPaymentsOnJoinCmd, IsCheckPaymentsOnJoinCmd,
-    CheckPaymentsDataCmd, EmailNoPaymentCmd, CheckNoPaymentCmd, RemoveNoPaymentCmd,
-    PaymentTaskStartCmd, PaymentTaskStopCmd, PaymentTaskInfoCmd,
-    PaymentTaskAddChatCmd, PaymentTaskRemoveChatCmd, PaymentTaskRemoveAllChatsCmd
+    AliveCmd, AuthUsersCmd, ChatInfoCmd, CheckNoPaymentCmd, CheckNoUsernameCmd, CheckPaymentsDataCmd, EmailNoPaymentCmd,
+    HelpCmd, InviteLinkCmd, IsCheckPaymentsOnJoinCmd, IsTestModeCmd, PaymentTaskAddChatCmd, PaymentTaskInfoCmd,
+    PaymentTaskRemoveAllChatsCmd, PaymentTaskRemoveChatCmd, PaymentTaskStartCmd, PaymentTaskStopCmd, RemoveNoPaymentCmd,
+    RemoveNoUsernameCmd, SetCheckPaymentsOnJoinCmd, SetTestModeCmd, UsersListCmd, VersionCmd
 )
-from telegram_payment_bot.config.configurable_object import ConfigurableObject
+from telegram_payment_bot.config.config_object import ConfigObject
 from telegram_payment_bot.logger.logger import Logger
 from telegram_payment_bot.translator.translation_loader import TranslationLoader
 
@@ -118,13 +117,13 @@ class CommandDispatcherConst:
 # Command dispatcher class
 class CommandDispatcher:
 
-    config: ConfigurableObject
+    config: ConfigObject
     logger: Logger
     translator: TranslationLoader
 
     # Constructor
     def __init__(self,
-                 config: ConfigurableObject,
+                 config: ConfigObject,
                  logger: Logger,
                  translator: TranslationLoader) -> None:
         self.config = config
